yakumo.cinder.v1.volume_type

Package yakumo :: Package cinder :: Package v1 :: Module volume_type |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.cinder.v1.volume_type

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for volumes on Block Storage V1 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('id', 'id', mapper.Noop),
    27      ('name', 'name', mapper.Noop),
    28      ('extra_specs', 'extra_specs', mapper.Noop),
    29  ]
    30
    31
    32 -class Resource(base.Resource):
    33      """resource class for volumes on Block Storage V1 API"""
    34
    35
    36 -class Manager(base.Manager):
    37      """manager class for roles on Block Storage V1 API"""
    38
    39      resource_class = Resource
    40      service_type = 'volume'
    41      _attr_mapping = ATTRIBUTE_MAPPING
    42      _json_resource_key = 'volume_type'
    43      _json_resources_key = 'volume_types'
    44      _hidden_methods = ["update"]
    45      _url_resource_list_path = '/types'
    46      _url_resource_path = '/types'
    47
    48 -    def create(self, name=UNDEF, extra_specs=UNDEF):
    49          """
    50          Register a volume type
    51
    52          @keyword name: Volume type name
    53          @type name: str
    54          @keyword extra_specs: Metadata (key=value)
    55          @type extra_specs: dict
    56          @return: Created volume type
    57          @rtype: yakumo.cinder.v1.volume_type.Resource
    58          """
    59          return super(Manager, self).create(name=name, extra_specs=extra_specs)
    60